#
# spec file for package python-colorama
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-colorama
Version:        0.4.4
Release:        lp152.4.3.1
Summary:        Cross-platform colored terminal text
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/tartley/colorama
Source:         https://github.com/tartley/colorama/archive/%{version}.tar.gz
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
BuildArch:      noarch
%python_subpackages

%description
Makes ANSI escape character sequences, for producing colored terminal text and
cursor positioning, work under MS Windows.

ANSI escape character sequences have long been used to produce colored terminal
text and cursor positioning on Unix and Macs. Colorama makes this work on
Windows, too. It also provides some shortcuts to help generate ANSI sequences,
and works fine in conjunction with any other ANSI sequence generation library,
such as Termcolor.

This has the upshot of providing a simple cross-platform API for printing
colored terminal text from Python, and has the happy side-effect that existing
applications or libraries which use ANSI sequences to produce colored output on
Linux or Macs can now also work on Windows, simply by calling colorama.init().

%prep
%setup -q -n colorama-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand script -eqc "pytest-%{$python_version} -vv -s" /dev/null

%files %{python_files}
%license LICENSE.txt
%doc CHANGELOG.rst README.rst
%doc demos/
%dir %{python_sitelib}/colorama
%{python_sitelib}/colorama/*
%dir %{python_sitelib}/colorama-%{version}-py*.egg-info
%{python_sitelib}/colorama-%{version}-py*.egg-info

%changelog
* Mon Dec 14 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update in SLE-15 (bsc#1176785, jsc#ECO-3105, jsc#PM-2352)
* Mon Oct 19 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.4.4:
  * Fixes
* Wed Apr  1 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.4.3
  * Several documentation & demo fixes.
* Sat Dec  1 2018 Arun Persaud <arun@gmx.de>
- update to version 0.4.1:
  * Fix issue #196: prevent exponential number of calls when calling
    'init' multiple times. Reported by bbayles and fixed by Delgan.
* Tue Nov 13 2018 Tomáš Chvátal <tchvatal@suse.com>
- Switch to github tarball to get tests
* Mon Nov 12 2018 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * move from tar.gz to zip on pypi
  * be more specific in %%files section
  * remove devel from noarch
- update to version 0.4.0:
  * Fix issue #142: reset LIGHT_EX colors with RESET_ALL. Reported by
    Delgan
  * Fix issue #147: ignore invalid "erase" ANSI codes. Reported by
    shin-
  * Fix issues #163 and #164: fix stream wrapping under
    PyCharm. Contributed by veleek and Delgan.
  * Thanks to jdufresne for various code cleanup and updates to
    documentation and project metadata.  (pull requests #171, #172,
    [#173], #174, #176, #177, #189, #190, #192)
  * #186: added contextlib magic methods to ansitowin32.StreamWrapper.
    Contributed by hoefling.
  * Fix issue #131: don't cache stdio handles, since they might be
    closed/changed by fd redirection. This fixes an issue with pytest.
    Contributed by segevfiner.
  * #146, #157: Drop support for EOL Python 2.5, 2.6, 3.1, 3.2 and
    3.3, and add 3.6. Thanks to hugovk.
* Fri Aug 25 2017 tbechtold@suse.com
- update to 0.3.9:
  * Revert fix for issue #103 which causes problems for dependent applications
* Tue Apr 25 2017 toddrme2178@gmail.com
- update to 0.3.8
  * Fix issue #121: "invalid escape sequence" deprecation fixes on Python 3.6+
  * Fix issue #110: fix "set console title" when working with unicode strings
  * Fix issue #103: enable color when using "input" function on Python 3.5+
  * Fix issue #95: enable color when stderr is a tty but stdout is not
- Implement single-spec version
- Fix source url.
* Tue Nov 15 2016 dmueller@suse.com
- update to 0.3.7:
  * Fix issue #84: check if stream has 'closed' attribute before testing it
  * Fix issue #74: objects might become None at exit
  * Fix issue #81: fix ValueError when a closed stream was used
  * Bumping version to re-upload a wheel distribution
  * Fix issue #47 and #80 - stream redirection now strips ANSI codes on Linux
  * Fix issue #53 - strip readline markers
  * Fix issue #32 - assign orig_stdout and orig_stderr when initialising
  * Fix issue #57 - Fore.RESET did not reset style of LIGHT_EX colors.
    Fixed by Andy Neff
  * Fix issue #51 - add context manager syntax. Thanks to Matt Olsen.
  * Fix issue #48 - colorama didn't work on Windows when environment
    variable 'TERM' was set.
  * Fix issue #54 - fix pylint errors in client code.
  * Changes to readme and other improvements by Marc Abramowitz and Zearin
* Sun Apr 19 2015 benoit.monin@gmx.fr
- update to 0.3.3:
  * Fix Google Code issue #13 - support changing the console title
    with OSC escape sequence
  * Fix Google Code issue #16 - Add support for Windows xterm
    emulators
  * Fix Google Code issue #30 - implement \033[nK (clear line)
  * Fix Google Code issue #49 - no need to adjust for scroll when
    new position is already relative (CSI n A\B\C\D)
  * Fix Google Code issue #55 - erase_data fails on Python 3.x
  * Fix Google Code issue #46 - win32.COORD definition missing
  * Implement \033[0J and \033[1J (clear screen options)
  * Fix default ANSI parameters
  * Fix position after \033[2J (clear screen)
  * Add command shortcuts: colorama.Cursor,
    colorama.ansi.set_title, colorama.ansi.clear_line,
    colorama.ansi.clear_screen
  * Fix issue #22 - Importing fails for python3 on Windows
  * Thanks to John Szakmeister for adding support for light colors
  * Thanks to Charles Merriam for adding documentation to demos
* Mon Sep 15 2014 tbechtold@suse.com
- update to 0.3.2:
  * Thanks to Marc Schlaich (schlamar) for a setup.py fix for Python2.5
  * Thanks to Jurko for fix on 64-bit Windows CPython2.5 w/o ctypes (issue #56)
  * Thanks to Remi Rampin for:
  * better github integration, incl rendered README and Travis config.
  * fixed forward slashes in README
  * Thanks to Florian Bruhin for fix when stdout or stderr are None
  * Thanks to Simeon Visser for:
  * closing a file handle using 'with'
  * updating classifiers to include Python 3.3 and 3.4
  * Thanks to Thomas Weininger for fix ValueError on Windows (issue #50)
* Tue Sep  2 2014 toddrme2178@gmail.com
- Update to 0.3.1
  * Fixed crash on exit with closed stdout, with thanks to Marc Abramowitz.
  * Now uses setuptools if available, and falls back to distutils if not.
  * setup.py no longer imports anything from colorama source.
- Update to 0.3.0
  * Move repository to Git, https://github.com/tartley/colorama. (My Mercurial
    repo seemed to be corrupted, I couldn't commit nor view patches of old
    commits, even on fresh checkouts.)
  * Fix always-crash on non-Windows platforms, reported by Matt McCormick.
  * Fix issue #47, incompatible with pyreadline.
* Thu Sep 26 2013 dmueller@suse.com
- update to 0.2.7:
  * Fix problem under 64-bit windows due to ctypes HANDLE size.
  * Fix licensing to the source files
* Mon Apr 29 2013 dmueller@suse.com
- update to 0.2.5:
  * various small bugfixes
* Mon Nov 19 2012 saschpe@suse.de
- Initial version
